@@ -24,6 +24,7 @@ import shutil
 import logging
 from random import choice, seed
 
+
 seed()
 logger = logging.getLogger('audiofield_log')
 
@@ -279,3 +280,18 @@ class AudioField(FileField):
         super(AudioField, self).contribute_to_class(cls, name)
         signals.post_save.connect(self._rename_audio, sender=cls)
         signals.post_init.connect(self._set_audio_converted, sender=cls)
+
+
+try:
+    from south.modelsinspector import add_introspection_rules
+    add_introspection_rules([(
+            [AudioField],
+            [],
+            {
+                "ext_whitelist": ["ext_whitelist", {}],
+            },
+        ),
+    ], ["^audiofield\.fields\.AudioField"])
+except ImportError:
+    #south is not enabled
+    pass
